@@ -28,7 +28,7 @@ __PACKAGE__->__dbfile($dbfile);
 
 __PACKAGE__->config(
     'Plugin::AutoCRUD' => {
-        extjs2 => '/static/ext2',
+        extjs2 => '/cpacstatic/ext2',
         basepath => '',
         # sites => { default => { frontend => 'skinny' } },
     },
